@@ -4,6 +4,7 @@ from optparse import make_option
 from textwrap import fill
 
 from django.core.management.base import BaseCommand, CommandError
+from django.utils.encoding import force_text
 
 from django_otp.plugins.otp_static.lib import get_user_model, add_static_token
 
@@ -25,4 +26,4 @@ class Command(BaseCommand):
         except get_user_model().DoesNotExist:
             raise CommandError('User "{0}" does not exist.'.format(username))
 
-        self.stdout.write(statictoken.token)
+        self.stdout.write(force_text(statictoken.token))
